/*
 * include file for libCW.h
 * cw_func calls
 */

#define WITH_CWIRC 0

#define RTS 1
#define PA  2

#if WITH_CWIRC == 1
#define CWIRC 4
#endif

int  cw_init (int newmode, char *name, char *ser);
int  cw_get_keyMode (void);
int  cw_set_keyMode (int newmode, char *pgmname);
char *cw_get_serdev ();
int  cw_set_doReply (int mode);
int  cw_get_doReply (void);
int  cw_set_wpm (int new_wpm);
int  cw_get_wpm (void);
int  cw_set_fwpm (int new_fwpm);
int  cw_get_fwpm (void);
int  cw_set_freq (int new_freq);
int  cw_get_freq (void);
int  cw_send_str  (char *str);
int  cw_send_word (char *str);
int  cw_send_char (char ch);
void cw_exit (void);

/************** end sendCW.h **************/
